
import logging


class ReductionMethod:
    log = logging.getLogger('exdf.data_reduction.ReductionMethod')

    # Stores list of instructions and can apply them
    # Allows (de-)serialization with files
    # Convenience interface for reduction methods to emit instructions.

    # Populate some arguments
    # Check if the method is enabled -> could be in the main body
    # Actually compile instructions for removal with DataCollection

    def __init__(self):
        self._instructions = []

    def __bool__(self):
        # Whether this program contains any instructions.
        return bool(self._instructions)

    def __len__(self):
        # How many instructions this program contains.
        return len(self._instructions)

    def select_trains(self, sources, trains):
        # init level
        self._instructions.append(('selectTrains', sources, trains))
        self.log.debug(f'Emitted {self._instructions[-1]}')

    def remove_sources(self, source_glob):
        # init level
        self._instructions.append(('removeSources', source_glob))
        self.log.debug(f'Emitted {self._instructions[-1]}')

    def remove_keys(self, source_glob, key_glob):
        # copy_dataset level
        self._instructions.append(('removeKeys', source_glob, key_glob))
        self.log.debug(f'Emitted {self._instructions[-1]}')

    def partial_copy(self, sources, key, region, chunks):
        self._instructions.append(
            ('partialCopy', sources, key, region, chunks))
        self.log.debug(f'Emitted {self._instructions[-1]}')
